@@ -1,4 +1,4 @@
-/* $Id: terminal-dialogs.c 28634 2008-11-06 16:44:14Z jannis $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>
  *
@@ -47,6 +47,7 @@ terminal_dialogs_show_about (GtkWindow *parent)
   static const gchar *authors[] =
   {
     "Benedikt Meurer <benny@xfce.org>",
+    "Nick Schermer <nick@xfce.org>",
     NULL,
   };
 
@@ -68,25 +69,31 @@ terminal_dialogs_show_about (GtkWindow *parent)
   /* try to load the about logo */
   logo = gdk_pixbuf_new_from_file_at_size (DATADIR "/icons/hicolor/scalable/apps/Terminal.svg", 168, 168, NULL);
 
-  /* open the about dialog */
+  /* set dialog hook on gtk versions older then 2.18 */
+#if !GTK_CHECK_VERSION (2, 18, 0)
+#if EXO_CHECK_VERSION (0, 5, 0)
+  gtk_about_dialog_set_email_hook (exo_gtk_url_about_dialog_hook, NULL, NULL);
+  gtk_about_dialog_set_url_hook (exo_gtk_url_about_dialog_hook, NULL, NULL);
+#else
   gtk_about_dialog_set_email_hook (exo_url_about_dialog_hook, NULL, NULL);
   gtk_about_dialog_set_url_hook (exo_url_about_dialog_hook, NULL, NULL);
+#endif
+#endif
+
+  /* open the about dialog */
   gtk_show_about_dialog (parent,
                          "authors", authors,
                          "artists", artists,
-                         "comments", _("X Terminal Emulator"),
+                         "comments", _("Xfce Terminal Emulator"),
                          "documenters", documenters,
                          "copyright", "Copyright \302\251 2003-2007 Benedikt Meurer",
                          "license", XFCE_LICENSE_GPL,
                          "logo", logo,
-#if GTK_CHECK_VERSION(2,11,0)
                          "program-name", PACKAGE_NAME,
-#else
-                         "name", PACKAGE_NAME,
-#endif
                          "translator-credits", _("translator-credits"),
                          "version", PACKAGE_VERSION,
-                         "website", "http://www.xfce.org/projects/terminal/",
+                         "website", "http://goodies.xfce.org/projects/applications/terminal",
+                         "website-label", _("Visit Terminal website"),
                          NULL);
 
   /* release the about logo (if any) */
@@ -123,7 +130,7 @@ terminal_dialogs_show_error (gpointer      parent,
   va_list    args;
   gchar     *primary_text;
 
-  _terminal_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
+  terminal_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
 
   /* determine the proper parent */
   if (parent == NULL)
