@@ -1,3 +1,4 @@
+#include <terminal/terminal-marshal.h>
 
 #include	<glib-object.h>
 
@@ -84,44 +85,7 @@ _terminal_marshal_OBJECT__VOID (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* VOID:STRING,ENUM (terminal-marshal.list:2) */
-void
-_terminal_marshal_VOID__STRING_ENUM (GClosure     *closure,
-                                     GValue       *return_value G_GNUC_UNUSED,
-                                     guint         n_param_values,
-                                     const GValue *param_values,
-                                     gpointer      invocation_hint G_GNUC_UNUSED,
-                                     gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__STRING_ENUM) (gpointer     data1,
-                                                  gpointer     arg_1,
-                                                  gint         arg_2,
-                                                  gpointer     data2);
-  register GMarshalFunc_VOID__STRING_ENUM callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
-
-  g_return_if_fail (n_param_values == 3);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__STRING_ENUM) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_marshal_value_peek_string (param_values + 1),
-            g_marshal_value_peek_enum (param_values + 2),
-            data2);
-}
-
-/* VOID:OBJECT,INT,INT (terminal-marshal.list:3) */
+/* VOID:OBJECT,INT,INT (terminal-marshal.list:2) */
 void
 _terminal_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                         GValue       *return_value G_GNUC_UNUSED,
