@@ -1,4 +1,4 @@
-/* $Id: terminal-widget.h 28985 2008-12-07 17:05:21Z nick $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2004-2005 os-cillation e.K.
  *
@@ -24,7 +24,7 @@
 
 #include <vte/vte.h>
 
-G_BEGIN_DECLS;
+G_BEGIN_DECLS
 
 #define TERMINAL_TYPE_WIDGET            (terminal_widget_get_type ())
 #define TERMINAL_WIDGET(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TERMINAL_TYPE_WIDGET, TerminalWidget))
@@ -33,17 +33,24 @@ G_BEGIN_DECLS;
 #define TERMINAL_IS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TERMINAL_TYPE_WIDGET))
 #define TERMINAL_WIDGET_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TERMINAL_TYPE_WIDGET, TerminalWidgetClass))
 
-/* VTE_CHECK_VERSION is available since VTE 0.17.1 */
-#ifndef VTE_CHECK_VERSION
-#define VTE_CHECK_VERSION(major,minor,micro) (0)
-#endif
+enum
+{
+  TARGET_URI_LIST,
+  TARGET_UTF8_STRING,
+  TARGET_TEXT,
+  TARGET_COMPOUND_TEXT,
+  TARGET_STRING,
+  TARGET_TEXT_PLAIN,
+  TARGET_MOZ_URL,
+  TARGET_APPLICATION_X_COLOR,
+  TARGET_GTK_NOTEBOOK_TAB
+};
 
 typedef struct _TerminalWidget      TerminalWidget;
 typedef struct _TerminalWidgetClass TerminalWidgetClass;
 
 GType      terminal_widget_get_type (void) G_GNUC_CONST;
-GtkWidget *terminal_widget_new      (void);
 
-G_END_DECLS;
+G_END_DECLS
 
 #endif /* !__TERMINAL_WIDGET_H__ */
