@@ -91,6 +91,11 @@ static void            terminal_window_set_size_force_grid           (TerminalWi
                                                                       TerminalScreen         *screen,
                                                                       gint                    force_grid_width,
                                                                       gint                    force_grid_height);
+static gboolean        terminal_window_accel_activate                (GtkAccelGroup          *accel_group,
+                                                                      GObject                *acceleratable,
+                                                                      guint                   accel_key,
+                                                                      GdkModifierType         accel_mods,
+                                                                      TerminalWindow         *window);
 static void            terminal_window_update_actions                (TerminalWindow         *window);
 static void            terminal_window_rebuild_gomenu                (TerminalWindow         *window);
 static void            terminal_window_notebook_page_switched        (GtkNotebook            *notebook,
@@ -215,29 +220,29 @@ static GQuark        gomenu_action_quark = 0;
 static const GtkActionEntry action_entries[] =
 {
   { "file-menu", NULL, N_ ("_File"), NULL, NULL, NULL, },
-  { "new-tab", TERMINAL_STOCK_NEWTAB, N_ ("Open _Tab"), NULL, N_ ("Open a new terminal tab"), G_CALLBACK (terminal_window_action_new_tab), },
-  { "new-window", TERMINAL_STOCK_NEWWINDOW, N_ ("Open T_erminal"), "<control><shift>N", N_ ("Open a new terminal window"), G_CALLBACK (terminal_window_action_new_window), },
-  { "detach-tab", NULL, N_ ("_Detach Tab"), NULL, N_ ("Open a new window for the current terminal tab"), G_CALLBACK (terminal_window_action_detach_tab), },
-  { "close-tab", TERMINAL_STOCK_CLOSETAB, N_ ("C_lose Tab"), NULL, N_ ("Close the current terminal tab"), G_CALLBACK (terminal_window_action_close_tab), },
-  { "close-window", TERMINAL_STOCK_CLOSEWINDOW, N_ ("_Close Window"), NULL, N_ ("Close the terminal window"), G_CALLBACK (terminal_window_action_close_window), },
+    { "new-tab", TERMINAL_STOCK_NEWTAB, N_ ("Open _Tab"), NULL, N_ ("Open a new terminal tab"), G_CALLBACK (terminal_window_action_new_tab), },
+    { "new-window", TERMINAL_STOCK_NEWWINDOW, N_ ("Open T_erminal"), "<control><shift>N", N_ ("Open a new terminal window"), G_CALLBACK (terminal_window_action_new_window), },
+    { "detach-tab", NULL, N_ ("_Detach Tab"), NULL, N_ ("Open a new window for the current terminal tab"), G_CALLBACK (terminal_window_action_detach_tab), },
+    { "close-tab", TERMINAL_STOCK_CLOSETAB, N_ ("C_lose Tab"), NULL, N_ ("Close the current terminal tab"), G_CALLBACK (terminal_window_action_close_tab), },
+    { "close-window", GTK_STOCK_QUIT, N_ ("_Close Window"), NULL, N_ ("Close the terminal window"), G_CALLBACK (terminal_window_action_close_window), },
   { "edit-menu", NULL, N_ ("_Edit"), NULL, NULL, NULL, },
-  { "copy", GTK_STOCK_COPY, N_ ("_Copy"), NULL, N_ ("Copy to clipboard"), G_CALLBACK (terminal_window_action_copy), },
-  { "paste", GTK_STOCK_PASTE, N_ ("_Paste"), NULL, N_ ("Paste from clipboard"), G_CALLBACK (terminal_window_action_paste), },
-  { "paste-selection", NULL, N_ ("Paste _Selection"), NULL, N_ ("Paste from primary selection"), G_CALLBACK (terminal_window_action_paste_selection), },
-  { "edit-toolbars", NULL, N_ ("_Toolbars..."), NULL, N_ ("Customize the toolbars"), G_CALLBACK (terminal_window_action_edit_toolbars), },
-  { "preferences", GTK_STOCK_PREFERENCES, N_ ("Pr_eferences..."), NULL, N_ ("Open the Terminal preferences dialog"), G_CALLBACK (terminal_window_action_prefs), },
+    { "copy", GTK_STOCK_COPY, N_ ("_Copy"), NULL, N_ ("Copy to clipboard"), G_CALLBACK (terminal_window_action_copy), },
+    { "paste", GTK_STOCK_PASTE, N_ ("_Paste"), NULL, N_ ("Paste from clipboard"), G_CALLBACK (terminal_window_action_paste), },
+    { "paste-selection", NULL, N_ ("Paste _Selection"), NULL, N_ ("Paste from primary selection"), G_CALLBACK (terminal_window_action_paste_selection), },
+    { "edit-toolbars", NULL, N_ ("_Toolbars..."), NULL, N_ ("Customize the toolbars"), G_CALLBACK (terminal_window_action_edit_toolbars), },
+    { "preferences", GTK_STOCK_PREFERENCES, N_ ("Pr_eferences..."), NULL, N_ ("Open the Terminal preferences dialog"), G_CALLBACK (terminal_window_action_prefs), },
   { "view-menu", NULL, N_ ("_View"), NULL, NULL, NULL, },
   { "terminal-menu", NULL, N_ ("_Terminal"), NULL, NULL, NULL, },
-  { "set-title", NULL, N_ ("_Set Title..."), NULL, N_ ("Set a custom title for the current tab"), G_CALLBACK (terminal_window_action_set_title), },
-  { "reset", GTK_STOCK_REFRESH, N_ ("_Reset"), NULL, NULL, G_CALLBACK (terminal_window_action_reset), },
-  { "reset-and-clear", GTK_STOCK_CLEAR, N_ ("Reset and C_lear"), NULL, NULL, G_CALLBACK (terminal_window_action_reset_and_clear), },
+    { "set-title", NULL, N_ ("_Set Title..."), NULL, N_ ("Set a custom title for the current tab"), G_CALLBACK (terminal_window_action_set_title), },
+    { "reset", GTK_STOCK_REFRESH, N_ ("_Reset"), NULL, NULL, G_CALLBACK (terminal_window_action_reset), },
+    { "reset-and-clear", GTK_STOCK_CLEAR, N_ ("Reset and C_lear"), NULL, NULL, G_CALLBACK (terminal_window_action_reset_and_clear), },
   { "go-menu", NULL, N_ ("_Go"), NULL, NULL, NULL, },
-  { "prev-tab", GTK_STOCK_GO_BACK, N_ ("_Previous Tab"), NULL, N_ ("Switch to previous tab"), G_CALLBACK (terminal_window_action_prev_tab), },
-  { "next-tab", GTK_STOCK_GO_FORWARD, N_ ("_Next Tab"), NULL, N_ ("Switch to next tab"), G_CALLBACK (terminal_window_action_next_tab), },
+    { "prev-tab", GTK_STOCK_GO_BACK, N_ ("_Previous Tab"), NULL, N_ ("Switch to previous tab"), G_CALLBACK (terminal_window_action_prev_tab), },
+    { "next-tab", GTK_STOCK_GO_FORWARD, N_ ("_Next Tab"), NULL, N_ ("Switch to next tab"), G_CALLBACK (terminal_window_action_next_tab), },
   { "help-menu", NULL, N_ ("_Help"), NULL, NULL, NULL, },
-  { "contents", GTK_STOCK_HELP, N_ ("_Contents"), NULL, N_ ("Display help contents"), G_CALLBACK (terminal_window_action_contents), },
-  { "report-bug", TERMINAL_STOCK_REPORTBUG, N_ ("_Report a bug"), NULL, N_ ("Report a bug in Terminal"), G_CALLBACK (terminal_window_action_report_bug), },
-  { "about", GTK_STOCK_ABOUT, N_ ("_About"), NULL, N_ ("Display information about Terminal"), G_CALLBACK (terminal_window_action_about), },
+    { "contents", GTK_STOCK_HELP, N_ ("_Contents"), NULL, N_ ("Display help contents"), G_CALLBACK (terminal_window_action_contents), },
+    { "report-bug", TERMINAL_STOCK_REPORTBUG, N_ ("_Report a bug"), NULL, N_ ("Report a bug in Terminal"), G_CALLBACK (terminal_window_action_report_bug), },
+    { "about", GTK_STOCK_ABOUT, N_ ("_About"), NULL, N_ ("Display information about Terminal"), G_CALLBACK (terminal_window_action_about), },
   { "input-methods", NULL, N_ ("_Input Methods"), NULL, NULL, NULL, },
 };
 
@@ -340,6 +345,8 @@ terminal_window_init (TerminalWindow *window)
 
   accel_group = gtk_ui_manager_get_accel_group (window->ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
+  g_signal_connect_after (G_OBJECT (accel_group), "accel-activate",
+      G_CALLBACK (terminal_window_accel_activate), window);
 
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), vbox);
@@ -651,6 +658,36 @@ terminal_window_set_size_force_grid (TerminalWindow *window,
 
 
 
+static gboolean
+terminal_window_accel_activate (GtkAccelGroup   *accel_group,
+                                GObject         *acceleratable,
+                                guint            accel_key,
+                                GdkModifierType  accel_mods,
+                                TerminalWindow  *window)
+{
+  GtkAction   *action;
+  const gchar *names[] = { "prev-tab", "next-tab" };
+  guint        n;
+  GtkAccelKey  key;
+
+  for (n = 0; n < G_N_ELEMENTS (names); n++)
+    {
+      /* pretend we handled the accelerator if the event matches one of
+       * the insensitive actions, so we don't send weird key events to vte
+       * see http://bugzilla.xfce.org/show_bug.cgi?id=3715 */
+      action = gtk_action_group_get_action (window->action_group, names[n]);
+      if (!gtk_action_is_sensitive (action)
+          && gtk_accel_map_lookup_entry (gtk_action_get_accel_path (action), &key)
+          && key.accel_key == accel_key
+          && key.accel_mods == accel_mods)
+        return TRUE;
+    }
+
+  return FALSE;
+}
+
+
+
 static void
 terminal_window_update_actions (TerminalWindow *window)
 {
@@ -937,11 +974,11 @@ terminal_window_notebook_page_removed (GtkNotebook    *notebook,
 
 
 
-#define EVENT_IN_ALLOCATION(event,widget) \
-  ((widget)->allocation.x <= (event)->x \
-  && (widget)->allocation.x + (widget)->allocation.width >= (event)->x \
-  && (widget)->allocation.y <= (event)->y \
-  && (widget)->allocation.y + (widget)->allocation.height >= (event)->y)
+#define EVENT_IN_ALLOCATION(event_x,event_y,widget) \
+  ((event_x) >= (widget)->allocation.x  \
+  && (event_x) <= (widget)->allocation.x + (widget)->allocation.width \
+  && (event_y) >= (widget)->allocation.y \
+  && (event_y) <= (widget)->allocation.y + (widget)->allocation.height)
 
 
 
@@ -953,17 +990,22 @@ terminal_window_notebook_button_press_event (GtkNotebook    *notebook,
   GtkWidget *page, *label, *menu;
   gint       page_num = 0;
   gboolean   close_middle_click;
+  gint       x, y;
 
   terminal_return_val_if_fail (TERMINAL_IS_WINDOW (window), FALSE);
   terminal_return_val_if_fail (GTK_IS_NOTEBOOK (notebook), FALSE);
 
+  gdk_window_get_position (event->window, &x, &y);
+  x += event->x;
+  y += event->y;
+
   if (event->button == 1)
     {
       if (event->type == GDK_2BUTTON_PRESS)
         {
           /* check if the user double-clicked on the label */
           label = gtk_notebook_get_tab_label (notebook, GTK_WIDGET (window->active));
-          if (EVENT_IN_ALLOCATION (event, label))
+          if (EVENT_IN_ALLOCATION (x, y, label))
             {
               terminal_window_action_set_title (NULL, window);
               return TRUE;
@@ -976,7 +1018,7 @@ terminal_window_notebook_button_press_event (GtkNotebook    *notebook,
       while ((page = gtk_notebook_get_nth_page (notebook, page_num)) != NULL)
         {
           label = gtk_notebook_get_tab_label (notebook, page);
-          if (EVENT_IN_ALLOCATION (event, label))
+          if (EVENT_IN_ALLOCATION (x, y, label))
             break;
           page_num++;
         }
